import {nodeResolve} from '@rollup/plugin-node-resolve'
import terser from '@rollup/plugin-terser'
import replace from '@rollup/plugin-replace'
import progress from 'rollup-plugin-progress';

const production = !(process.env.ROLLUP_WATCH),
    sourcemap = !production

const banner = `
/*!
 * Metro UI DOM Manipulation Library  (https://metroui.org.ua)
 * Copyright 2012-${new Date().getFullYear()} by Serhii Pimenov
 * Licensed under MIT
 *
 * Build time: ${new Date().toLocaleDateString()} ${new Date().toLocaleTimeString()}
 !*/
`

export default [
    {
        input: './src/browser.js',
        watch: {
            include: 'src/**',
            clearScreen: false
        },
        plugins: [
            progress({
                clearLine: true,
            }),
            replace({
                preventAssignment: true,
            }),
            nodeResolve({
                browser: true
            }),
        ],
        output: [
            {
                file: './build/m4q.js',
                format: 'iife',
                sourcemap,
                banner,
            },
            {
                file: './build/m4q.min.js',
                format: 'iife',
                sourcemap,
                banner,
                plugins: [
                    terser({
                        keep_classnames: true,
                        keep_fnames: true,
                    })
                ]
            },
        ]
    },
];